@@ -211,12 +211,38 @@ def cli_generator(obj):
     Generator(obj["project"], obj["config"], obj["tokens"]).run()
 
 
-@main.command("aggregator", help="Manage CNAMEs of aggregators in QA envs")
-@click.option("-l", "--list", "show_list", required=False, count=True)
-@click.option("-c", "--change", "change", required=False, count=True)
+@main.group(
+    "aggregator",
+    help="Manage CNAMEs of aggregators in QA envs",
+    invoke_without_command=True,
+)
+@click.option(
+    "-l", "--list", "show_list", help="deprecated", required=False, count=True
+)
+@click.option("-c", "--change", "change", help="deprecated", required=False, count=True)
+@click.pass_context
+def aggregator(ctx, show_list, change):
+    if show_list == 1 or change == 1:
+        logger.error(
+            "suite-py aggregator [-c|-l] has been hard-deprecated. Use suite-py aggregator [list|change] instead."
+        )
+        sys.exit(0)
+
+    if ctx.invoked_subcommand is None:
+        logger.error("Missing command. Try suite-py aggregator --help for help.")
+        sys.exit(0)
+
+
+@aggregator.command("list", help="List all aggregators with the current record")
 @click.pass_obj
-def cli_aggregator(obj, show_list, change):
-    Aggregator(obj["config"], show_list, change).run()
+def cli_aggregator_list(obj):
+    Aggregator(obj["config"], "list").run()
+
+
+@aggregator.command("change", help="Change aggregator record")
+@click.pass_obj
+def cli_aggregator_change(obj):
+    Aggregator(obj["config"], "change").run()
 
 
 @main.command("login", help="manage login against Auth0")
